# UnimodDB

![Python package](https://github.com/ikcgroup/unimoddb/workflows/Python%20package/badge.svg)
[![codecov](https://codecov.io/gh/ikcgroup/unimoddb/branch/master/graph/badge.svg)](https://codecov.io/gh/ikcgroup/unimoddb)


UnimodDB is a library for providing a SQLite interface to the Unimod database of
protein modifications.

# Table of Contents

- [Installation](#installation)
- [License](#license)

# Installation

`unimoddb` can be installed from [PyPI](https://pypi.org/project/unimoddb/).

### Compatibility

`unimoddb` is written using Python 3 and should be compatible with most 
operating systems. The package has been tested on
- Windows 10
- MacOS 10.15
- Ubuntu 18.04 LTS

### Instructions

1. Install Python 3 (>= version 3.6).
2. Install the latest version of the `unimoddb` library using `pip`:
```shell script
pip install unimoddb
```

# License

`unimoddb` is released under the terms of the [MIT license](https://github.com/ikcgroup/unimoddb/blob/master/LICENSE).